# PAIAGym Examples

## Usage

Rename the `.env.template` file to `.env` in the directory, and make some changes.

Make sure you have already installed `paiagym`.

To train the model, use the following command at the same location as the `ml_play.py`:
```
paiagym train
```

To run the inference, use the following command at the same location as the `ml_play.py`:
```
paiagym run
```